@@ -375,6 +375,10 @@ class With(Expression):
     arg_types = {"expressions": True, "recursive": False}
 
 
+class WithinGroup(Expression):
+    arg_types = {"this": True, "expression": False}
+
+
 class CTE(Expression):
     arg_types = {"this": True, "alias": True}
 
@@ -420,6 +424,10 @@ class Exists(Expression):
     arg_types = {"this": True, "not": False}
 
 
+class Filter(Expression):
+    arg_types = {"this": True, "expression": True}
+
+
 class From(Expression):
     arg_types = {"expressions": True}
 
@@ -534,6 +542,10 @@ class Property(Expression):
     arg_types = {"this": True, "value": True}
 
 
+class Qualify(Expression):
+    pass
+
+
 class Table(Expression):
     arg_types = {"this": True, "db": False, "catalog": False}
 
@@ -609,6 +621,7 @@ class Select(Subqueryable, Expression):
         "where": False,
         "group": False,
         "having": False,
+        "qualify": False,
         "order": False,
         "limit": False,
         "offset": False,
