@@ -84,6 +84,7 @@ class Parser:
         TokenType.ENGINE,
         TokenType.EXPLAIN,
         TokenType.FALSE,
+        TokenType.FILTER,
         TokenType.FOLLOWING,
         TokenType.IF,
         TokenType.INTERVAL,
@@ -94,6 +95,7 @@ class Parser:
         TokenType.OVER,
         TokenType.PERCENT,
         TokenType.PRECEDING,
+        TokenType.QUALIFY,
         TokenType.RANGE,
         TokenType.ROWS,
         TokenType.SCHEMA_COMMENT,
@@ -785,6 +787,7 @@ class Parser:
                     "where": self._parse_where(),
                     "group": self._parse_group(),
                     "having": self._parse_having(),
+                    "qualify": self._parse_qualify(),
                     "order": self._parse_order(),
                     "limit": self._parse_limit(),
                     "offset": self._parse_offset(),
@@ -999,6 +1002,11 @@ class Parser:
             return None
         return self.expression(exp.Having, this=self._parse_conjunction())
 
+    def _parse_qualify(self):
+        if not self._match(TokenType.QUALIFY):
+            return None
+        return self.expression(exp.Qualify, this=self._parse_conjunction())
+
     def _parse_order(self):
         if not self._match_by(TokenType.ORDER):
             return None
@@ -1435,6 +1443,23 @@ class Parser:
         return self.expression(exp.Cast if strict else exp.TryCast, this=this, to=to)
 
     def _parse_window(self, this):
+        if self._match(TokenType.FILTER):
+            self._match_l_paren()
+            this = self.expression(
+                exp.Filter, this=this, expression=self._parse_where()
+            )
+            self._match_r_paren()
+
+        if self._match(TokenType.WITHIN_GROUP):
+            self._match_l_paren()
+            this = self.expression(
+                exp.WithinGroup,
+                this=this,
+                expression=self._parse_order(),
+            )
+            self._match_r_paren()
+            return this
+
         if not self._match(TokenType.OVER):
             return this
 
