@@ -109,6 +109,7 @@ class TokenType(AutoName):
     EXPLAIN = auto()
     EXTRACT = auto()
     FALSE = auto()
+    FILTER = auto()
     FOLLOWING = auto()
     FULL = auto()
     FROM = auto()
@@ -149,6 +150,7 @@ class TokenType(AutoName):
     PRECEDING = auto()
     PRIMARY_KEY = auto()
     PROPERTIES = auto()
+    QUALIFY = auto()
     RANGE = auto()
     RECURSIVE = auto()
     REPLACE = auto()
@@ -177,6 +179,7 @@ class TokenType(AutoName):
     WHEN = auto()
     WHERE = auto()
     WITH = auto()
+    WITHIN_GROUP = auto()
     WITHOUT = auto()
     ZONE = auto()
 
@@ -302,6 +305,7 @@ class Tokenizer:
         "EXPLAIN": TokenType.EXPLAIN,
         "EXTRACT": TokenType.EXTRACT,
         "FALSE": TokenType.FALSE,
+        "FILTER": TokenType.FILTER,
         "FULL": TokenType.FULL,
         "FOLLOWING": TokenType.FOLLOWING,
         "FROM": TokenType.FROM,
@@ -340,6 +344,7 @@ class Tokenizer:
         "PERCENT": TokenType.PERCENT,
         "PRECEDING": TokenType.PRECEDING,
         "PRIMARY KEY": TokenType.PRIMARY_KEY,
+        "QUALIFY": TokenType.QUALIFY,
         "RANGE": TokenType.RANGE,
         "RECURSIVE": TokenType.RECURSIVE,
         "REGEXP": TokenType.RLIKE,
@@ -371,6 +376,7 @@ class Tokenizer:
         "WHEN": TokenType.WHEN,
         "WHERE": TokenType.WHERE,
         "WITH": TokenType.WITH,
+        "WITHIN GROUP": TokenType.WITHIN_GROUP,
         "WITHOUT": TokenType.WITHOUT,
         "ZONE": TokenType.ZONE,
         "ARRAY": TokenType.ARRAY,
